# NOTE: this is a Linux-specific package, don't use the embedded
# viewer on non-Linux platforms.

#%%global __provides_exclude xpcom

# list of plugins to be wrapped by default ex: libflashplayer,nppdf
# these are wrapped by default on 32->64 use only
%define nspw_plugins flashplayer,nppdf,rpnp,nphelix

# define 32-bit arch of multiarch platforms
%define arch_32 %{nil}
%ifarch x86_64
%define arch_32 i386
%endif

# define to build a biarch package
%define build_biarch		0
%if "%{_arch}:%{arch_32}" == "x86_64:i386"
%define build_biarch		1
%endif

%{expand: %{?_with_biarch:	%%global build_biarch 1}}
%{expand: %{?_without_biarch:	%%global build_biarch 0}}

# define target architecture of plugins we want to support
%define target_arch i386

# define target operating system of plugins we want to support
%define target_os linux

# define nspluginswrapper libdir (invariant, including libdir)
%define pkglibdir %{_prefix}/lib/%{name}

# define mozilla plugin dir
%define plugindir %{_libdir}/mozilla/plugins

Summary:	A compatibility layer for Netscape 4 plugins
Name:		nspluginwrapper
Version:	1.4.4
Release:	%mkrel 11
License:	GPLv2+
Group:		Networking/WWW
URL:		http://nspluginwrapper.davidben.net/
Source0:	http://nspluginwrapper.davidben.net/download/nspluginwrapper-%{version}.tar.gz
Source2:	nspluginwrapper.script
Source3:	update-nspluginwrapper
Patch7:         nspluginwrapper-enable-v4l1compat.patch
# fixes build, submitted:
# https://github.com/davidben/nspluginwrapper/issues/43
Patch8:		nspluginwrapper-glib-includes.patch
# from upstream, fixes build
Patch9:		nspluginwrapper-link-dl.patch
# fixes build, similar patch submitted upstream:
# https://www.redhat.com/archives/nspluginwrapper-devel-list/2011-November/msg00000.html
Patch10:	nspluginwrapper-link-gthread.patch
# (tv) fix build with newer glib:
Patch11:		nspluginwrapper-glib-thread.patch
# Fix parallel build
Patch12:	nspluginwrapper-parallel-build.patch

BuildRequires:	curl-devel
BuildRequires:	gtk+2-devel
BuildRequires:	libxt-devel
Provides:	%{name}-%{_arch} = %{version}-%{release}
Requires(post):	 %{name}-%{target_arch} = %{version}-%{release}
Requires(preun): %{name}-%{target_arch} = %{version}-%{release}
ExcludeArch:	%mips %arm

%description
nspluginwrapper makes it possible to use Netscape 4 compatible plugins
compiled for %{target_os}/%{target_arch} into Mozilla for another architecture, e.g. x86_64.

This package consists in:
  * npviewer: the plugin viewer
  * npwrapper.so: the browser-side plugin
  * nspluginwrapper: a tool to manage plugins installation and update

%if %{build_biarch}
%package %{target_arch}
Summary:	A viewer for %{target_os}/%{target_arch} compiled Netscape 4 plugins
Group:		Networking/WWW
%if "%{target_arch}" == "i386"
# Flash 10 now requires 32 bit libcurl, libnss3.so 
# but Adobe's RPM package does not require them...
# http://blogs.adobe.com/penguin.swf/2008/08/curl_tradeoffs.html
Recommends:       libcurl.so.4
Recommends:	libnss3.so
%endif

%description %{target_arch}
nspluginwrapper makes it possible to use Netscape 4 compatible plugins
compiled for %{target_os}/%{target_arch} into Mozilla for another architecture,
e.g. x86_64.

This package consists in:
  * npviewer: the plugin viewer
  * npwrapper.so: the browser-side plugin
  * nspluginwrapper: a tool to manage plugins installation and update

This package provides the npviewer program for %{target_os}/%{target_arch}.
%endif

%prep

%setup -q
%autopatch -p1

%build
export CFLAGS="$RPM_OPT_FLAGS"
export CXXFLAGS="$RPM_OPT_FLAGS"

%if %{build_biarch}
biarch="--enable-biarch"
%else
biarch="--disable-biarch"
%endif
mkdir objs
pushd objs
../configure \
	--prefix=%{_prefix} \
	--target-cpu=%{target_arch} \
	--enable-viewer \
	$biarch \
	--target-os=linux --disable-strip
%make
popd

%install
make -C objs install DESTDIR=%{buildroot}

mkdir -p %{buildroot}%{plugindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig/nspluginwrapper

touch %{buildroot}%{_sysconfdir}/sysconfig/nspluginwrapper

ln -s %{pkglibdir}/%{_arch}/%{_os}/npwrapper.so %{buildroot}%{plugindir}/npwrapper.so

install -m 0755 %{SOURCE2} %{buildroot}%{_sbindir}
install -m 0755 %{SOURCE3} %{buildroot}%{_sbindir}

# filetrigger for registering installed plugins:
%transfiletriggerin -- /usr/lib/mozilla/plugins/ /usr/lib/flash-plugin/
nspluginwrapper.script

%post
if [ ! -f %{_sysconfdir}/sysconfig/nspluginwrapper ]; then
    cat > %{_sysconfdir}/sysconfig/nspluginwrapper <<EOF
USE_NSPLUGINWRAPPER=yes
MGA_PLUGINS="%{nspw_plugins}"
USER_PLUGINS=""
EOF
else
    if ! grep -q ^MGA_PLUGINS= %{_sysconfdir}/sysconfig/nspluginwrapper; then
        echo "MGA_PLUGINS=\"%{nspw_plugins}\"" >> %{_sysconfdir}/sysconfig/nspluginwrapper
    else
        sed -i "s/MGA_PLUGINS=.*/MGA_PLUGINS=\"%{nspw_plugins}\"/" \
            %{_sysconfdir}/sysconfig/nspluginwrapper
    fi
fi

%{_sbindir}/nspluginwrapper.script || :

%preun
if [ $1 = 0 ]; then
  %{_bindir}/%{name} -v -a -r
fi

# Only use for these when on 64-bit
%if %{build_biarch}

# Flash Player
%triggerin -- flash-plugin
if [ -f %{plugindir}/npwrapper.libflashplayer.so ]; then
  %{_bindir}/%{name} -v -u %{plugindir}/npwrapper.libflashplayer.so
else
  %{_bindir}/%{name} -v -i /usr/lib/flash-plugin/libflashplayer.so
fi

%triggerpostun -- flash-plugin
if [ ! -f /usr/lib/flash-plugin/libflashplayer.so ]; then
  %{_bindir}/%{name} -v -r %{plugindir}/npwrapper.libflashplayer.so
fi

# Acrobat Reader
%triggerin -- acroread5-nppdf, acroread-nppdf
if [ -f %{plugindir}/npwrapper.nppdf.so ]; then
  %{_bindir}/%{name} -v -u %{plugindir}/npwrapper.nppdf.so
else
  %{_bindir}/%{name} -v -i /usr/lib/mozilla/plugins/nppdf.so
fi

%triggerpostun -- acroread5-nppdf, acroread-nppdf
if [ ! -f /usr/lib/mozilla/plugins/nppdf.so ]; then
  %{_bindir}/%{name} -v -r %{plugindir}/npwrapper.nppdf.so
fi

# Real Player 8
%triggerin -- RealPlayer-rpnp < 10
if [ -f %{plugindir}/npwrapper.rpnp.so ]; then
  %{_bindir}/%{name} -v -u %{plugindir}/npwrapper.rpnp.so
else
  %{_bindir}/%{name} -v -i /usr/lib/mozilla/plugins/rpnp.so
fi

%triggerpostun -- RealPlayer-rpnp < 10
if [ ! -f /usr/lib/mozilla/plugins/rpnp.so ]; then
  %{_bindir}/%{name} -v -r %{plugindir}/npwrapper.rpnp.so
fi

# Real Player 10
%triggerin -- RealPlayer-rpnp >= 10
if [ -f %{plugindir}/npwrapper.nphelix.so ]; then
  %{_bindir}/%{name} -v -u %{plugindir}/npwrapper.nphelix.so
else
  %{_bindir}/%{name} -v -i /usr/lib/mozilla/plugins/nphelix.so
fi

%triggerpostun -- RealPlayer-rpnp >= 10
if [ ! -f /usr/lib/mozilla/plugins/nphelix.so ]; then
  %{_bindir}/%{name} -v -r %{plugindir}/npwrapper.nphelix.so
fi

%endif

%files
%doc NEWS README TODO
%{_bindir}/%{name}
%{_bindir}/nspluginplayer
%{_sbindir}/update-nspluginwrapper
%{_sbindir}/nspluginwrapper.script
%ghost %{_sysconfdir}/sysconfig/nspluginwrapper
%{plugindir}/npwrapper.so
%dir %{pkglibdir}
%dir %{pkglibdir}/noarch
%{pkglibdir}/noarch/npviewer.sh
%dir %{pkglibdir}/%{_arch}
%dir %{pkglibdir}/%{_arch}/%{_os}
%{pkglibdir}/%{_arch}/%{_os}/npconfig
%if ! %{build_biarch}
%{pkglibdir}/%{_arch}/%{_os}/npviewer
%{pkglibdir}/%{_arch}/%{_os}/npviewer.bin
%{pkglibdir}/%{_arch}/%{_os}/libnoxshm.so
%endif
%{pkglibdir}/%{_arch}/%{_os}/npplayer
%{pkglibdir}/%{_arch}/%{_os}/npwrapper.so

%if %{build_biarch}
%files %{target_arch}
%dir %{pkglibdir}/%{target_arch}
%dir %{pkglibdir}/%{target_arch}/%{target_os}
%{pkglibdir}/%{target_arch}/%{target_os}/npviewer
%{pkglibdir}/%{target_arch}/%{target_os}/npviewer.bin
%{pkglibdir}/%{target_arch}/%{target_os}/libnoxshm.so
%endif


%changelog
* Mon Apr 18 2016 blino <blino> 1.4.4-11.mga6
+ Revision: 1003530
- fix nspluginwrapper.script path in post scriptlet (got broken in r873746)

* Fri Feb 19 2016 umeabot <umeabot> 1.4.4-10.mga6
+ Revision: 969729
- Mageia 6 Mass Rebuild

* Sun Sep 06 2015 tv <tv> 1.4.4-9.mga6
+ Revision: 873764
- fix "Macro expanded in comment"
- switch to new upstream file trigger syntax
  (also drop lib64 from filetrigger path as the script ignore that path)

* Wed Oct 15 2014 umeabot <umeabot> 1.4.4-8.mga5
+ Revision: 748085
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.4-7.mga5
+ Revision: 682936
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes
    - s/uggests:/Recommends:/

* Fri Jun 27 2014 pterjan <pterjan> 1.4.4-6.mga5
+ Revision: 640498
- Try fixing parallel build

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild
    - Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 24 2012 tv <tv> 1.4.4-4.mga3
+ Revision: 309536
- patch 11: fix build with newer glib
- loseteup requires is dup

  + anssi <anssi>
    - fix build (link-gthread.patch, link-dl.patch, glib-includes.patch)
    - use nspluginwrapper.script in %%post instead of wrapping all plugins
      which conflicts with nspluginwrapper.script
    - fix use of MDV_PLUGINS in nspluginwrapper.script
    - fix %%post in case of non-existing $MGA_PLUGINS in
      /etc/sysconfig/nspluginwrapper
    - do not try to wrap 64-bit plugins as we don't build 64-bit npviewer
    - do not try to wrap 32-bit plugins on 32-bit systems as the browsers
      nowadays support running plugins in dedicated processes themselves

* Thu Sep 08 2011 tv <tv> 1.4.4-1.mga2
+ Revision: 141190
- new release
- fix source URL
- fix %%setup call
- use %%setup -c
- new release

* Wed Jun 15 2011 ahmad <ahmad> 1.4.2-1.mga2
+ Revision: 106372
- Update to 1.4.2
- Change the url(s) to the new upstream website
- Drop the old sparc and ppc bits (we don't have them at all now)
- Drop patch0,8 ; note needed any more
- Drop the buildroot declaration
- Adapt to the new configure options, and use disable-strip instread of touching
  config-host.mak
- Nit: S/MDV_PLUGINS/MGA_PLUGINS/
- Drop some old/unneeded Flash Player triggers
- Update the file list (no more xpcom, until upstream supports it)

* Mon Apr 04 2011 tv <tv> 1.3.0-7.mga1
+ Revision: 80560
- clean up
- imported package nspluginwrapper


* Wed Nov 03 2010 Götz Waschk <waschk@mandriva.org> 1.3.0-7mdv2011.0
+ Revision: 593023
- fix build with gcc 4.5 (spturtle)
- fix provides

* Tue Mar 30 2010 Pascal Terjan <pterjan@mandriva.org> 1.3.0-5mdv2010.1
+ Revision: 529690
- Have __sprintf_chk to do its job (except for the check)

* Tue Mar 30 2010 Pascal Terjan <pterjan@mandriva.org> 1.3.0-4mdv2010.1
+ Revision: 529679
- Define __stack_chk_fail_local and __sprintf_chk as they are needed by statically linked libsupc++

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt for 2010.1

  + Olivier Blin <oblin@mandriva.com>
    - do not build on mips & arm (from Arnaud Patard)

* Sat May 02 2009 Frederik Himpe <fhimpe@mandriva.org> 1.3.0-1mdv2010.0
+ Revision: 370394
- Update to new version 1.3.0
- Remove patch for performance imporvements implemented upstream

* Fri Jan 02 2009 Frederik Himpe <fhimpe@mandriva.org> 1.2.2-1mdv2009.1
+ Revision: 323359
- Update to new version 1.2.2

* Sun Dec 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.0-1mdv2009.1
+ Revision: 320703
- Release 1.2.0
- Remove patch11 (merged upstream)

* Thu Dec 18 2008 Frederic Crozat <fcrozat@mandriva.com> 1.1.10-1mdv2009.1
+ Revision: 315498
- Release 1.1.10
- Remove patch11 (merged upstream)
- Patch11 (SVN): mimic FF3 behaviour in plugin release

* Wed Dec 03 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.8-1mdv2009.1
+ Revision: 309816
- Update to new version 1.1.8
- Resync Fedora patches

* Tue Oct 28 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.2-3mdv2009.1
+ Revision: 298056
- Add fix for assertion with Flash 10

* Sun Oct 26 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.2-2mdv2009.1
+ Revision: 297494
- Use event patch instead of sleep patch, like Fedora is doing. It
  should improve stability with Flash 10
- Suggest libnss3.so for Flash 10 (bug #45322)

* Thu Oct 16 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.2-1mdv2009.1
+ Revision: 294449
- Update to new version 1.1.2
- Remove 2 patches integrated upstream
- Add suggests: libcurl.so.4 on nspluginwrapper-i386, because Flash
  10 now requires this

* Wed Oct 15 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.0-8mdv2009.1
+ Revision: 294083
- Sync with Fedora patches:
  * Updated visual id fix for windowless crash with Flash 10 and Firefox 3
    (use the patch which is integrated in upstream svn now)
  * Concurrent rpc_method_invoke() patch (fixes some Flash crashes)

* Wed Sep 17 2008 Tiago Salem <salem@mandriva.com.br> 1.1.0-7mdv2009.0
+ Revision: 285564
- add LD_PRELOAD to v4l1compat.so.0
- bump release

* Thu Sep 04 2008 Tiago Salem <salem@mandriva.com.br> 1.1.0-6mdv2009.0
+ Revision: 280849
- add rpm filetrigger to handle new plugins
- add file to configure nspluginwrapper behavior
- add update-nspluginwrapper script to manage nspluginwrapper
- bump release

* Sat Aug 16 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.0-5mdv2009.0
+ Revision: 272764
- Extend postin script and triggers to deal with flash-plugin RPM
  downloaded from the Adobe site

* Thu Aug 14 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.0-4mdv2009.0
+ Revision: 272194
- Don't provide libxpcom.so (bug #42790)

* Wed Aug 06 2008 Frederik Himpe <fhimpe@mandriva.org> 1.1.0-3mdv2009.0
+ Revision: 264846
- Add Fedora patch fixing RH crasher bug #456432

* Mon Jul 21 2008 Olivier Blin <oblin@mandriva.com> 1.1.0-2mdv2009.0
+ Revision: 239260
- fix filelist for x86_64
- buildrequire curl-devel (for the standalone player)
- add selected fixes from the Fedora package
- package nspluginplayer
- package new npplayer and libnoxshm plugins
- 1.1.0

* Mon Jun 30 2008 Oden Eriksson <oeriksson@mandriva.com> 1.0.0-1mdv2009.0
+ Revision: 230202
- 1.0.0
- drop upstream implemented patches

* Thu Jun 26 2008 Oden Eriksson <oeriksson@mandriva.com> 0.9.91.5-4mdv2009.0
+ Revision: 229267
- add triggers for FlashPlayer-plugin (#39969) (Luc Menut)
- modify triggers for FlashPlayer consequently (FlashPlayer < 9.0.115.0) (Luc Menut)

* Tue Jun 24 2008 Tiago Salem <salem@mandriva.com.br> 0.9.91.5-3mdv2009.0
+ Revision: 228762
- fix focus issue in Adobe Acrobat 8

* Sun Feb 03 2008 Frederik Himpe <fhimpe@mandriva.org> 0.9.91.5-2mdv2008.1
+ Revision: 161581
- Add part of Debian's patch to patch0 in order to make it compile on x86_64
- Add patch0 from Fedora (and also included in Debian, Ubuntu and upstream) which fixes Flash 9.0.115 on SMP systems (http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=458584 and https://bugzilla.redhat.com/show_bug.cgi?id=360891)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 27 2007 Funda Wang <fwang@mandriva.org> 0.9.91.5-1mdv2008.0
+ Revision: 71706
- New version 0.9.91.5

* Fri Jun 29 2007 Funda Wang <fwang@mandriva.org> 0.9.91.4-1mdv2008.0
+ Revision: 45625
- New verison
  Patch 0,1 merged upstream


* Wed Mar 28 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91.3-2mdv2007.1
+ Revision: 149180
- don't error out when host plugins are tried, simply ignore them
- requires linux32 for nspluginwrapper-i386

* Sun Mar 04 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91.3-1mdv2007.1
+ Revision: 132209
- 0.9.91.3
  * fix printing with EMBED plugins
  * use sound wrappers whenever possible on Linux (Flash Player 9)
  * don't wait for dying processes (i.e. avoid hangs on NP_Shutdown)

* Fri Dec 29 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91.2-1mdv
- 0.9.91.2
  * improve error handling with non-blocking I/O
  * fix hangs when the plugin exits unexpectedly (e.g. a crash)

* Wed Dec 27 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91.2-0.20061227.1mdv
- update from SVN head (2006/12/27):
  * fix some rare RPC synchronisation issues (flashearth.com with flashplayer 9)

* Tue Dec 26 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91.1-1mdv
- 9.9.91.1
  * fix NPRuntime bridge (VLC plugin)
  * fix potential buffer overflow in RPC marshalers
  * handle empty args for plugin creation (flasharcade.com)

* Fri Dec 22 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-1mdv
- 0.9.91
  * add npruntime scripting support
  * disable flashplayer 9 beta 1 plugin

* Wed Dec 20 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-0.20061220.1mdv
- update from SVN head (2006/12/20):
  * really fix ppc64 host support
  * add NPN_RequestRead() support (acroread)
  * fix some rare hangs (add delayed requests)
  * fix libstdc++2 compat glue for broken plugins
  * improve marshaling of NPP instances (prepare integration of npruntime support)

* Fri Dec 15 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-0.20061215.1mdv
- fix requires
- update from SVN head (2006/12/15):
  * fix ppc64 / ppc32 support
  * create user mozilla plugins directory if it does not exist yet

* Wed Dec 13 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-0.20061213.1mdv
- update from SVN head (2006/12/13):
  * fix focus problems with certain Flash sites
  * add XEMBED support (mplayer plug-in)
  * add dummy XPCOM library

* Tue Nov 28 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-0.20061127.2mdv
- fix symlink to main wrapper plugin (cosmetics)

* Mon Nov 27 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.91-0.20061127.1mdv
- update from SVN head (2006/11/27):
  * cross-platform improvements
  * write wrapped plugin only when it is valid
  * embed LSB Desktop because other distros can't build biarch packages

* Fri Nov 17 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.90.4-1mdv
- 0.9.90.4
  * fix a warning
  * use glib hash tables

* Wed Nov 15 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.90.4-0.20061115.1mdv
- update from SVN head (2006/11/15) for testing:
  * add printing support (NPP_Print)
  * add initial support for Konqueror
  * fix post data to a URL (NPN_PostURL, NPN_PostURLNotify)
  * reduce plugin load times
  * robustify error condition (Darryl L. Miles)

* Wed Sep 20 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.90.3-1mdv
- fix acrobat reader 7 plugin
- fix triggers (for foreign package uninstallation this time)

* Mon Sep 18 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.90.2-2mdv
- fix triggers
- add triggers for Real Player 8

* Sat Sep 16 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.9.90.2-1mdk
- buildrequires: libxt-devel (neoclust)
- use a bidirectional communication channel

* Thu Jun 08 2006 Gwenole Beauchesne <gb.public@free.fr> 0.9.90.1-2mdk
- ship with mkruntime
- enable -debug packages
- add possibility to build biarch packages at once
- fix repackage.sh to stop generating deps on non x86 platforms

* Wed Jun 07 2006 Gwenole Beauchesne <gb.public@free.fr> 0.9.90.1-1mdk
- first Mandriva Linux release
- don't use QEMU on IA-64 platforms

